#!/bin/bash

## SAMPLE. Change the NFS mount points to match your environment
NFS_PROFILE_DIR=10.0.0.1:/STORAGE/profiles/
NFS_TOOLKIT_DIR=10.0.0.1:/TOOLKIT/


export PROFILENAME=${img}

## Internal Variables, do not modify
export TOOLKIT=/TOOLKIT
export NFS_MAIN=/mnt/nfs
export HWDISC_FILE=/TOOLKIT/hpdiscovery.xml
export SERVERNAME=
export BOOTDEVNODE=

clear
echo "*** Capturing Configuration ***"

echo "Mounting NFS share"
mkdir ${NFS_MAIN}
mount -t nfs ${NFS_TOOLKIT_DIR} ${NFS_MAIN} -o ro,nolock
if [ $? != 0 ]; then
	echo "Unable to mount NFS share, make sure you updated the $0 script with the location of your NFS server."
	exec /bin/bash
fi

echo "Copying over toolkit scripts and utilites from NFS share"
cd ${TOOLKIT}
cp -a ${NFS_MAIN}/scripts/* ${TOOLKIT}
cp -a ${NFS_MAIN}/utilities/* ${TOOLKIT}
mkdir -p ${TOOLKIT}/data_files/

umount ${NFS_MAIN}

echo ""
echo "Loading storage drivers for hardware"
./load_modules.sh


echo ""
echo "Pausing to allow drivers to finish loading"
sleep 15
echo ""

cd ${TOOLKIT}

## rerun hardware discovery 
./hpdiscovery -f ${HWDISC_FILE}
echo "Hardware Discovery saved to ${HWDISC_FILE}"


## use hwquery to fetch the SystemName and BootDeviceNode from hardware discovery file. ( extra " " are required ) 
export "`./hwquery ${HWDISC_FILE} allboards.xml SERVERTYPE=SystemName`"
export "`./hwquery ${HWDISC_FILE} allboards.xml BOOTDEVNODE=DevNode`";

echo "Server Type: ${SERVERTYPE}"

./conrep -s -fdata_files/conrep.dat
if [ $? = 0 ] ; then
	echo "System Configuration saved to ${TOOLKIT}/data_files/conrep.dat"
fi

./ifhw ${HWDISC_FILE} allboards.xml "PCI:Smart Array" 2> /dev/null
if [ $? = 0 ] ; then
	cd ${TOOLKIT}/cpqacuxe
	./cpqacuxe -c ../data_files/cpqacuxe.dat
	if [ $? = 0 ] ; then
		echo "Array Configuration saved to ${TOOLKIT}/data_files/cpqacuxe.dat"
	fi
else
	echo "No Smart Array detected, no ACU Configuration captured."
fi

cd ${TOOLKIT}

./ifhw ${HWDISC_FILE} allboards.xml "PCI:Integrated Lights-Out" 2> /dev/null
if [ $? = 0 ] ; then
	insmod /opt/compaq/cpqci/driver/cpqci.ko
	./hponcfg -w data_files/hponcfg.dat 
	if [ $? = 0 ] ; then
		echo "Integrated Lights-Out Configuration Report saved to ${TOOLKIT}/data_files/hponcfg.dat"
		echo " - this is not a RIBCL configuration script"
	fi
fi

if [ "$img" = "" ] ; then
        echo "No image name specified, add img=<name> parameter to the boot line to capture a complete profile."
        echo "System configuration captured to /TOOLKIT/data_files/"
        echo "copy these files to another location, then type exit or CTRL-D to reboot"
        /bin/bash
        ${TOOLKIT}/reboot
fi

echo "Mounting NFS Storage ${NFS_PROFILE_DIR}"
mount -t nfs ${NFS_PROFILE_DIR} ${NFS_MAIN} -o rw,nolock
if [ $? = 0 ] ; then
	mkdir ${NFS_MAIN}/$PROFILENAME
	cp -a ${TOOLKIT}/data_files ${NFS_MAIN}/$PROFILENAME

	partimage -z1 -o -d save ${BOOTDEVNODE} ${NFS_MAIN}/$PROFILENAME/bootdrive.img
	if [ $? = 0 ] ; then
		echo ""
		echo " System Captured to $PROFILENAME"
	fi
	umount ${NFS_PROFILE_DIR}
fi


sleep 30
${TOOLKIT}/reboot
