#!/bin/bash

## SAMPLE. Change the NFS mount points to match your environment
NFS_PROFILE_DIR=10.0.0.1:/STORAGE/profiles/
NFS_TOOLKIT_DIR=10.0.0.1:/TOOLKIT/


export PROFILENAME=${img}

## Internal Variables, do not modify
export TOOLKIT=/TOOLKIT
export NFS_MAIN=/mnt/nfs
export HWDISC_FILE=/TOOLKIT/hpdiscovery.xml
export SERVERNAME=
export BOOTDEVNODE=

clear
echo "*** Capturing Configuration ***"

echo "Mounting NFS share"
mkdir ${NFS_MAIN}
mount -t nfs ${NFS_TOOLKIT_DIR} ${NFS_MAIN} -o ro,nolock
if [ $? != 0 ]; then
	echo "Unable to mount NFS share, make sure you updated the $0 script with the location of your NFS server."
	exec /bin/bash
fi

echo "Copying over toolkit scripts and utilites from NFS share"
cd ${TOOLKIT}
cp -a ${NFS_MAIN}/scripts/* ${TOOLKIT}
cp -a ${NFS_MAIN}/utilities/* ${TOOLKIT}

umount ${NFS_MAIN}

echo ""
echo "Loading storage drivers for hardware"
./load_modules.sh


echo ""
echo "Pausing to allow drivers to finish loading"
sleep 15
echo ""

cd ${TOOLKIT}

./hpdiscovery -f ${HWDISC_FILE}

## use hwquery to fetch the SystemName from hardware discovery file. ( extra " " are required ) 
export "`./hwquery ${HWDISC_FILE} allboards.xml SERVERTYPE=SystemName`";

echo "Server Type: ${SERVERTYPE}"

echo "Mounting NFS Storage ${NFS_PROFILE_DIR}"
mount -t nfs ${NFS_PROFILE_DIR} ${NFS_MAIN} -o rw,nolock
if [ $? = 0 ] ; then
	echo "APPLYING ${PROFILENAME}
	cp -a ${NFS_MAIN}/${PROFILENAME}/data_files ${TOOLKIT}

	./conrep -l -fdata_files/conrep.dat
	if [ $? = 0 ] ; then
		echo "System Configuration data_files/conrep.dat APPLIED"
	else
		echo "System Configuration data_files/conrep.dat FAILED"
	fi

	./ifhw ${HWDISC_FILE} allboards.xml "PCI:Smart Array" 2> /dev/null
	if [ $? = 0 ] ; then
		cd ${TOOLKIT}/cpqacuxe
		./cpqacuxe -i ../data_files/cpqacuxe.dat
		if [ $? = 0 ] ; then
			echo "Array Configuration data_files/cpqacuxe.dat APPLIED"
		else
			echo "Array Configuration data_files/cpqacuxe.dat FAILED"
		fi
	else
		echo "No Smart Array detected, no ACU Configuration applied."
	fi

	cd ${TOOLKIT}

	./ifhw ${HWDISC_FILE} allboards.xml "PCI:Integrated Lights-Out" 2> /dev/null
	if [ $? = 0 ] ; then
		insmod /opt/compaq/cpqci/driver/cpqci.ko
		./hponcfg -f data_files/hponcfg.dat 
		if [ $? = 0 ] ; then
			echo "Integrated Lights-Out Configuration data_files/hponcfg.dat APPLIED"
		fi
	fi

	export "`./hwquery ${HWDISC_FILE} allboards.xml BOOTDEVNODE=DevNode`";

	partimage restore ${BOOTDEVNODE} ${NFS_MAIN}/${PROFILENAME}/bootdrive.img
	if [ $? = 0 ] ; then
		echo ""
		echo " System Captured to $PROFILENAME"
	fi

	umount ${NFS_PROFILE_DIR}
fi

sleep 30
${TOOLKIT}/reboot
