#!/bin/bash

## SAMPLE. Change the NFS mount points to match your environment
export NFS_TOOLKIT_DIR=10.0.0.1:/TOOLKIT

## Internal Variables, do not modify
export TOOLKIT=/TOOLKIT
export NFS_MAIN=/mnt/nfs
export HWDISC_FILE=/TOOLKIT/hpdiscovery.xml
export SERVERNAME=

clear
echo -e "*** Upgrading Firmware ***"

echo "Mounting NFS share"
mkdir ${NFS_MAIN}
mount -t nfs ${NFS_TOOLKIT_DIR} ${NFS_MAIN} -o ro,nolock
if [ $? != 0 ]; then
	echo "Unable to mount NFS share, make sure you updated the $0 script with the location of your NFS server."
	exec /bin/bash
fi

echo "Copying over toolkit scripts, utilites and firmware components from NFS share"
cd ${TOOLKIT}
cp -a ${NFS_MAIN}/scripts/* ${TOOLKIT}
cp -a ${NFS_MAIN}/utilities/* ${TOOLKIT}
cp -a ${NFS_MAIN}/firmware ${TOOLKIT}


echo ""
echo "Loading storage drivers for hardware"
./load_modules.sh

echo ""
echo "Pausing to allow drivers to finish loading"
sleep 15

echo ""
echo "Detecting Hardware"

## run hardware discovery 
./hpdiscovery -f ${HWDISC_FILE}

## use hwquery to fetch the SystemName from hardware discovery file. ( extra " " are required ) 
export "`./hwquery ${HWDISC_FILE} allboards.xml SERVERNAME=SystemName`";

echo "Server Type: ${SERVERNAME}"

if [ "${SERVERNAME}" = "ProLiant DL360 G4p" ]; then
	echo -n "Updating ProLiant DL360 G4p"
	${TOOLKIT}/firmware/cp006164.scexe -s >/dev/null 2>/dev/null
	if [ $? != 0 ]; then
		echo -e "  -ROM is already up to date, no update needed\n"
	else
		echo -e "  -ROM updated"
	fi
	sleep 2s
fi

# Smart Array 5i Controller
# PCI ID: 0E11B1780E114080
./ifhw ${HWDISC_FILE} allboards.xml "PCI:Smart Array 5i Controller" 2>/dev/null
if [ $? = 0 ]; then
	echo -n Updating "Smart Array 5i Controller"
	${TOOLKIT}/firmware/cp005327.scexe -s >/dev/null 2>/dev/null
	if [ $? != 0 ]; then
		echo -e "  -ROM is already up to date, no update needed\n"
	else
		echo -e "  -ROM updated"
	fi
	sleep 2s
fi

cd ${TOOLKIT}

## unmount disk
umount ${NFS_MAIN}

